summaryrefslogtreecommitdiff
path: root/config/environments
diff options
context:
space:
mode:
authorAzul <azul@leap.se>2013-09-20 14:22:28 +0200
committerAzul <azul@leap.se>2013-09-20 14:22:28 +0200
commit985406273233905868c70918bafd767d8870c76a (patch)
tree2b1ab7c9e89f2aaae379938430f40e5b3babfbbf /config/environments
parent13e91941396a74b6245dcb9d81b9cfa77861df95 (diff)
parent890c9e170fc038eccb46eca3c1ddcf6f05eaa53f (diff)
Merge tag '0.2.3'
Diffstat (limited to 'config/environments')
-rw-r--r--config/environments/production.rb11
1 files changed, 6 insertions, 5 deletions
diff --git a/config/environments/production.rb b/config/environments/production.rb
index 32b4558..73e98e5 100644
--- a/config/environments/production.rb
+++ b/config/environments/production.rb
@@ -33,11 +33,12 @@ LeapWeb::Application.configure do
# See everything in the log (default is :info)
# config.log_level = :debug
- # Prepend all log lines with the following tags
- # config.log_tags = [ :subdomain, :uuid ]
-
- # Use a different logger for distributed setups
- # config.logger = ActiveSupport::TaggedLogging.new(SyslogLogger.new)
+ # Use syslog if no file has been specified
+ if APP_CONFIG[:logfile].blank?
+ # Prepend all log lines with the following tags
+ config.log_tags = [ :leap, :webapp ]
+ config.logger = ActiveSupport::TaggedLogging.new(SyslogLogger.new)
+ end
# Use a different cache store in production
# config.cache_store = :mem_cache_store